@@ -565,15 +565,14 @@ class AbstractTextRange:
         return self.document().token(self.pos)
 
     def tokens(self):
-        """Convenience method returning a tuple with all Tokens that are in
-        or overlap this text range.
+        """Convenience method yielding all Tokens that are in or overlap this
+        text range.
 
         The Document must have the :class:`~parce.treedocument.TreeDocument`
         class mixed in (i.e. have the ``get_root()`` method.
 
         """
-        root = self.document().get_root(True)
-        return tuple(root.tokens_range(self.pos, self.end))
+        return self.document().get_root(True).tokens_range(self.pos, self.end)
 
 
 class Cursor(AbstractTextRange):
@@ -721,3 +720,13 @@ class Block(AbstractTextRange):
             pos = self.document().find_start_of_block(end)
             return type(self)(self.document(), pos, end)
 
+    def tokens(self):
+        """Convenience method returning a tuple with all Tokens that are in
+        or overlap this block.
+
+        The Document must have the :class:`~parce.treedocument.TreeDocument`
+        class mixed in (i.e. have the ``get_root()`` method.
+
+        """
+        return tuple(super().tokens())
+
