@@ -32,7 +32,7 @@ from parce.action import (
     Number, Operator, Separator, String, Text)
 from parce.rule import (
     MATCH, TEXT, arg, bygroup, call, dselect, findmember, ifarg, ifeq, ifgroup,
-    ifmember, select, words)
+    ifmember, select, using, words)
 
 from . import lilypond_words
 
@@ -362,12 +362,19 @@ class LilyPond(Language):
                 "--": LyricHyphen,
                 "__": LyricExtender,
                 "_": LyricSkip,
-            }, LyricText)
+            }, using(cls.lyricword))
         yield RE_FRACTION, Number.Fraction
         yield RE_LILYPOND_DURATION, Duration, cls.duration
         yield from cls.common()
         yield from cls.commands(list_target=cls.start_list)
 
+    @lexicon
+    def lyricword(cls):
+        """Contents of lyric word, highlight tie and space separately."""
+        yield '~', LyricText.Tie
+        yield '_', LyricText.Space
+        yield default_action, LyricText
+
     # ---------------------- drummode ---------------------
     @lexicon
     def drummode(cls):
@@ -551,8 +558,8 @@ class LilyPond(Language):
     @classmethod
     def _markup_rules(cls, *extra_target):
         r"""Markup rules. Specify ``-1`` if outside an environment."""
-        yield r'\{', Bracket.Markup.Start, *extra_target, cls.markuplist
-        yield r"(\\score(?:-lines)?)\s*(\{)", bygroup(Name.Function.Markup, Bracket.Start), *extra_target, cls.markupscore
+        yield (r'\{', Bracket.Markup.Start, *extra_target, cls.markuplist)
+        yield (r"(\\score(?:-lines)?)\s*(\{)", bygroup(Name.Function.Markup, Bracket.Start), *extra_target, cls.markupscore)
         if extra_target:
             # count the arguments of markup commands and stack markup contexts
             yield RE_LILYPOND_COMMAND, cls.get_markup_action(), \
@@ -563,7 +570,7 @@ class LilyPond(Language):
         yield from cls.find_string(*extra_target)
         yield from cls.find_scheme(*extra_target)
         yield from cls.find_comment()
-        yield RE_LILYPOND_MARKUP_TEXT, Text, *extra_target
+        yield (RE_LILYPOND_MARKUP_TEXT, Text, *extra_target)
 
     @classmethod
     def get_markup_argument_count(cls, command):
@@ -587,7 +594,7 @@ class LilyPond(Language):
     @classmethod
     def find_scheme(cls, *extra_target):
         """Find scheme."""
-        yield r'[#$]', Delimiter.ModeChange.SchemeStart, *extra_target, cls.get_scheme_target()
+        yield (r'[#$]', Delimiter.ModeChange.SchemeStart, *extra_target, cls.get_scheme_target())
 
     @classmethod
     def get_scheme_target(cls):
@@ -605,7 +612,7 @@ class LilyPond(Language):
     @classmethod
     def find_string(cls, *extra_target):
         """Find a string."""
-        yield '"', String, *extra_target, cls.string
+        yield ('"', String, *extra_target, cls.string)
 
     @lexicon(consume=True)
     def string(cls):
@@ -618,8 +625,8 @@ class LilyPond(Language):
     @classmethod
     def find_comment(cls, *extra_target):
         """Find single-line or block comments."""
-        yield r'%\{', Comment, *extra_target, cls.multiline_comment
-        yield r'%', Comment, *extra_target, cls.singleline_comment
+        yield (r'%\{', Comment, *extra_target, cls.multiline_comment)
+        yield (r'%', Comment, *extra_target, cls.singleline_comment)
 
     @lexicon(consume=True)
     def multiline_comment(cls):
