@@ -113,6 +113,12 @@ music_commands = (
     'autoAccidentals',
     'autoBeamOff',
     'autoBeamOn',
+    'autoBreaksOff',            # since 2.20
+    'autoBreaksOn',             # since 2.20
+    'autoLineBreaksOff',            # since 2.20
+    'autoLineBreaksOn',             # since 2.20
+    'autoPageBreaksOff',            # since 2.20
+    'autoPageBreaksOn',             # since 2.20
     'autochange',
     'balloonGrobText',
     'balloonLengthOff',
@@ -129,8 +135,8 @@ music_commands = (
     'blackTriangleMarkup',
     'bookOutputName',
     'bookOutputSuffix',
-    'bracketCloseSymbol',
-    'bracketOpenSymbol',
+    'bracketCloseSymbol',   # removed in 2.18
+    'bracketOpenSymbol',    # removed in 2.18
     'break',
     'breathe',
     'cadenzaOff',
@@ -159,7 +165,9 @@ music_commands = (
     'dashLarger',
     'dashPlus',
     'dashUnderscore',
-    'deadNote',  # since 2.16
+    'deadNote',         # since 2.16
+    'deadNotesOff',     # since 2.20
+    'deadNotesOn',      # since 2.20
     'default',
     'defaultNoteHeads',  # since 2.16
     'defaultTimeSignature',
@@ -188,11 +196,11 @@ music_commands = (
     'endSpanners',
     'episemFinis',
     'episemInitium',
-    'escapedBiggerSymbol',
-    'escapedExclamationSymbol',
-    'escapedParenthesisCloseSymbol',
-    'escapedParenthesisOpenSymbol',
-    'escapedSmallerSymbol',
+    'escapedBiggerSymbol',              # removed in 2.18
+    'escapedExclamationSymbol',         # removed in 2.18
+    'escapedParenthesisCloseSymbol',    # removed in 2.18
+    'escapedParenthesisOpenSymbol',     # removed in 2.18
+    'escapedSmallerSymbol',             # removed in 2.18
     'expandFullBarRests',
     'featherDurations',
     'fermataMarkup',
@@ -208,6 +216,8 @@ music_commands = (
     'grace',
     'graceSettings',
     'harmonic',
+    'harmonicsOff',
+    'harmonicsOn',
     'hideNotes',
     'hideStaffSwitch',
     'huge',
@@ -229,13 +239,15 @@ music_commands = (
     'italianChords',
     'keepWithTag',
     'key',
+    'kievanOff',            # since 2.20
+    'kievanOn',             # since 2.20
     'killCues',
     'label',
     'large',
     'ligature',
     'linea',
     'maininput',
-    'majorSevenSymbol',
+    #'majorSevenSymbol',    # not used as a command
     'makeClusters',
     'mark',
     'markLengthOff', # since 2.18
@@ -269,8 +281,8 @@ music_commands = (
     'palmMute',  # since 2.16
     'palmMuteOn',  # since 2.16
     'parallelMusic',
-    'parenthesisCloseSymbol',
-    'parenthesisOpenSymbol',
+    'parenthesisCloseSymbol',       # removed in 2.18
+    'parenthesisOpenSymbol',        # removed in 2.18
     'parenthesize',
     'partcombine',
     'partCombineListener',
@@ -284,7 +296,7 @@ music_commands = (
     'phrasingSlurNeutral',
     'phrasingSlurSolid',
     'phrasingSlurUp',
-    'pipeSymbol',
+    'pipeSymbol',                   # removed in 2.18
     'pitchedTrill',
     'pointAndClickOff',
     'pointAndClickOn',
@@ -365,7 +377,7 @@ music_commands = (
     'tieNeutral',
     'tieSolid',
     'tieUp',
-    'tildeSymbol',
+    'tildeSymbol',          # removed in 2.18
     'time',
     'times',    # not mentioned since 2.18 (superseded by \tuplet)
     'timing',
@@ -400,6 +412,8 @@ music_commands = (
     'walkerHeadsMinor',
     'whiteTriangleMarkup',
     'withMusicProperty',
+    'xNotesOff',
+    'xNotesOn',
 )
 
 
@@ -760,6 +774,7 @@ contexts = (
     'MensuralVoice',
     'NoteNames',
     'NullVoice',     # since 2.18
+    'OneStaff',      # since 2.20
     'PetrucciStaff', # since 2.16
     'PetrucciVoice', # since 2.16
     'PianoStaff',
@@ -769,7 +784,7 @@ contexts = (
     'StaffGroup',
     'TabStaff',
     'TabVoice',
-    'Timing',
+    'Timing',        # not a real context, but an alias created by Timing_translator
     'VaticanaStaff',
     'VaticanaVoice',
     'Voice',
@@ -786,6 +801,7 @@ grobs = (
     'AmbitusNoteHead',
     'Arpeggio',
     'BalloonTextItem',
+    'BalloonTextSpanner',   # since 2.22
     'BarLine',
     'BarNumber',
     'BassFigure',
@@ -813,6 +829,7 @@ grobs = (
     'DoublePercentRepeat',
     'DoublePercentRepeatCounter',
     'DoubleRepeatSlash',
+    'DurationLine',         # since 2.22
     'DynamicLineSpanner',
     'DynamicText',
     'DynamicTextSpanner',
@@ -829,6 +846,7 @@ grobs = (
     'GridPoint',
     'Hairpin',
     'HorizontalBracket',
+    'HorizontalBracketText',    # since 2.20
     'InstrumentName',
     'InstrumentSwitch',
     'KeyCancellation',
@@ -845,11 +863,13 @@ grobs = (
     'LyricText',
     'MeasureCounter',
     'MeasureGrouping',
+    'MeasureSpanner',           # since 2.22
     'MelodyItem',
     'MensuralLigature',
     'MetronomeMark',
     'MultiMeasureRest',
     'MultiMeasureRestNumber',
+    'MultiMeasureRestScript',   # since 2.22
     'MultiMeasureRestText',
     'NonMusicalPaperColumn',
     'NoteCollision',
