@@ -143,9 +143,9 @@ class Lexicon:
         self.re_flags = descriptor._re_flags
         #: Whether this lexicon wants the token(s) that switched to it
         self.consume = descriptor._consume
-        #: The argument the lexicon was called with (creating a derived
-        #: Lexicon). None for a normal lexicon.
-        self.arg = arg
+        # The argument the lexicon was called with (creating a derived
+        # Lexicon). None for a normal lexicon.
+        self._arg = arg
         #: The short name (name of the method this Lexicon was defined with)
         self.name = descriptor.rules_func.__name__
         #: The short name with the Language name prepended, like
@@ -156,8 +156,17 @@ class Lexicon:
         self.qualname = language.__module__ + '.' + self.fullname
         self.__doc__ = descriptor.rules_func.__doc__
         self._derived = {}
-        # lock is used when creating a derivate and/or the parse() instance function
-        self._lock = threading.Lock()
+        # locks are used when creating a derivate and/or the parse() instance function
+        self._lock_derive = threading.Lock()
+        self._lock_build = threading.Lock()
+
+    @property
+    def arg(self):
+        """The argument the lexicon was called with (creating a derived
+        Lexicon). None for a normal lexicon.
+
+        """
+        return self._arg
 
     def __call__(self, arg=None):
         """Create a derived Lexicon with argument ``arg``.
@@ -190,7 +199,7 @@ class Lexicon:
         try:
             return self._derived[arg]
         except KeyError:
-            with self._lock:
+            with self._lock_derive:
                 try:
                     lexicon = self._derived[arg]
                 except KeyError:
@@ -211,12 +220,16 @@ class Lexicon:
 
     @util.cached_property
     def _rules(self):
-        """Yield the rules.
+        """Return all rules in a tuple.
 
-        Rule items that depend on the lexicon argument are not yet evaluated.
+        Rule items that depend on the lexicon argument are only evaluated if
+        this is a derived lexicon.
 
         """
-        return tuple(self.descriptor.rules_func(self.language) or ())
+        rules = self.descriptor.rules_func(self.language) or ()
+        if self.arg is not None:
+            rules = (pre_evaluate_rule(rule, self.arg) for rule in rules)
+        return tuple(rules)
 
     @util.cached_property
     def rules(self):
@@ -236,7 +249,7 @@ class Lexicon:
         argument are already evaluated.
 
         """
-        yield from self.rules if self.arg is not None else self._rules
+        yield from self._rules
 
     def __repr__(self):
         s = self.fullname
@@ -253,7 +266,7 @@ class Lexicon:
 
         """
         if name in ("parse",):
-            with self._lock:
+            with self._lock_build:
                 try:
                     return object.__getattribute__(self, name)
                 except AttributeError:
